import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map.Entry;

/**
 * Lab 8
 *
 * Driver, runs user through
 * the process of battling heroes.
 *
 * @author Stephen
 * @version 2017-10-04
 */
public class Driver
{
    /**
     * Arena in which heroes battle and from which we can get information about heroes.
     */
    private static HeroArena arena;
    
    /**
     * Prompts the user to either choose a Superhero or
     * list all Superhero.  Prints out information about
     * the chosen Superhero or all Superhero in heroMap.
     *
     * @param args Command line arguments.
     * @throws IOException Error during I/O operation.
     */
    public static void main(String[] args) throws IOException 
    {
        // Setup program to read user input.
        BufferedReader br = new BufferedReader(
            new InputStreamReader(System.in));

        String input; // The user's input.
        String heroChoice1; // The first Hero chosen by the user.
        String heroChoice2; // The second Hero chosen by the user.
        int menuChoice; // The menu option chosen by the user.

        // Set up the hero arena:
        arena = new HeroArena();

        //print the menu options
        System.out.println("As master of the intergalactic arena, you may choose two superheroes to fight against each"
                + " other. You may also view their hero information.\nPlease select an option:");

        System.out.println("1: Choose two Superheroes to battle");
        System.out.println("2: List all Superhero");

        while (true) // Loop until the user chooses a valid menu option.
        {
            try
            {
                input = br.readLine();
                menuChoice = Integer.parseInt(input);
                
                if (menuChoice <= 0 || menuChoice > 2)
                {
                    System.out.println("Please choose either 1 or 2.");
                }
                else
                {
                    break;
                }
            }
            catch (NumberFormatException e)
            {
                System.out.println("Please enter an integer.");
            } 
        }
        
        switch(menuChoice)
        {
            case 1:
            {
                // List the Superheroes that the user can choose from.
                System.out.println(
                    "Please choose from the following Superheroes: " +
                    arena.getHeroAbbreivations());

                heroChoice1 = br.readLine().toUpperCase();
                Superhero hero1 = arena.getHero(heroChoice1);
                
                // Loop until the user has entered a valid abbreviated heros' name.
                while (hero1 == null)
                {
                    System.out.println(
                        "Please choose one of the Superheroes listed.");

                    heroChoice1 = br.readLine().toUpperCase();
                    hero1 = arena.getHero(heroChoice1);
                }

                System.out.printf("You choose %s.\n", hero1);
                
                // List the Superheroes that the user can choose from.
                System.out.println(
                    "Please choose another hero from the following Superheroes: " +
                    arena.getHeroAbbreivations());

                heroChoice2 = br.readLine().toUpperCase();
                Superhero hero2 = arena.getHero(heroChoice2);
                
                // Loop until the user has entered a valid abbreviated heros' name.
                while (hero2 == null)
                {
                    System.out.println(
                        "Please choose one of the Superheroes listed.");

                    heroChoice2 = br.readLine().toUpperCase();
                    hero2 = arena.getHero(heroChoice2);
                }

                System.out.printf("You choose %s.\n", hero2);
                
                // Battle the superheroes and print the result:
                
                Superhero victor = arena.battleHeroes(hero1, hero2);

                if (victor == null)
                {
                    System.out.println("The battle was a tie!");
                }
                else
                {
                    System.out.printf("%s was the victor!", victor.name().toLowerCase());
                }

                break;
            }

            case 2:
            {
                //List the superheroes:
                System.out.println(arena.listHeroes());
                
                break;
            }
        }
    }
}
